@@ -8,7 +8,7 @@ use base qw(
     DateTime::Format::Natural::Wrappers
 );
 
-our $VERSION = '1.38';
+our $VERSION = '1.39';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -59,7 +59,7 @@ sub _daytime_variant
         afternoon => AFTERNOON,
         evening   => EVENING,
     );
-    my $hour = $self->{Daytime}{$daytime}
+    my $hour = exists $self->{Daytime}{$daytime}
       ? $self->{Daytime}{$daytime}
       : $daytimes{$daytime};
     if ($self->_valid_time(hour => $hour)) {
